<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing directory - click for web UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="97"/>
        <location filename="../gui/traywidget.cpp" line="269"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="392"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="71"/>
        <location filename="../gui/traywidget.cpp" line="743"/>
        <location filename="../gui/traywidget.cpp" line="785"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="110"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="123"/>
        <source>Open Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="283"/>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="290"/>
        <source>Incoming traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="222"/>
        <location filename="../gui/traywidget.ui" line="242"/>
        <location filename="../gui/traywidget.ui" line="293"/>
        <location filename="../gui/traywidget.ui" line="313"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="212"/>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="219"/>
        <source>Global overall statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="229"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="239"/>
        <source>Local overall statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="300"/>
        <source>Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="310"/>
        <source>Outgoing traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="354"/>
        <location filename="../gui/traywidget.cpp" line="148"/>
        <location filename="../gui/traywidget.cpp" line="312"/>
        <source>New notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="384"/>
        <source>Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="416"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="448"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="476"/>
        <source>Recent changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="512"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="522"/>
        <source>Dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="120"/>
        <source>View own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="125"/>
        <source>Restart Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="130"/>
        <source>Show Syncthing log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="135"/>
        <source>Rescan all directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="142"/>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="164"/>
        <source>Show internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="179"/>
        <source>Quit Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="367"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="393"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="405"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="406"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="411"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="412"/>
        <source>At least one device is paused, click to resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="517"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="547"/>
        <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="558"/>
        <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="601"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="605"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="608"/>
        <source>Copy directory ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="739"/>
        <location filename="../gui/traywidget.cpp" line="779"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="740"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="744"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="57"/>
        <source>Unable to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="90"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="114"/>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="115"/>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="124"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
